@@ -308,7 +308,7 @@ class ImagenTrainer(nn.Module):
 
     def train_step(self, unet_number = None, **kwargs):
         self.create_train_iter()
-        loss = self.step_with_dl_iter(self.train_dl_iter, unet_number = unet_number, *kwargs)
+        loss = self.step_with_dl_iter(self.train_dl_iter, unet_number = unet_number, **kwargs)
         self.update(unet_number = unet_number)
         return loss
 
@@ -496,6 +496,11 @@ class ImagenTrainer(nn.Module):
         self.reset_ema_unets_all_one_device()
         return super().load_state_dict(*args, **kwargs)
 
+    # encoding text functions
+
+    def encode_text(self, text, **kwargs):
+        return self.imagen.encode_text(text, **kwargs)
+
     # forwarding functions and gradient step updates
 
     def scale(self, loss, *, unet_number):
